=====================
``columns`` module
=====================

.. automodule:: whoosh.columns


Base classes
============

.. autoclass:: Column
    :members:

.. autoclass:: ColumnWriter
    :members:

.. autoclass:: ColumnReader
    :members:


Basic columns
=============

.. autoclass:: VarBytesColumn

.. autoclass:: FixedBytesColumn

.. autoclass:: RefBytesColumn

.. autoclass:: NumericColumn


Technical columns
=================

.. autoclass:: BitColumn

.. autoclass:: CompressedBytesColumn

.. autoclass:: StructColumn

.. autoclass:: PickleColumn


Experimental columns
====================

.. autoclass:: ClampedNumericColumn

